Class: AnywayAppConfig::Loaders::FlatYAML

Inherits:
Anyway::Loaders::YAML
  • Object
show all
Defined in:
lib/anyway_app_config/loaders/flat_yaml.rb

Overview

YAML loader that always treats the file as a flat key/value document, ignoring environment sections regardless of file content or global state.